@@ -90,6 +90,18 @@ class Action:
             },
         )
 
+    def sendFriendTeXiaoText(self, user: int, text: str) -> dict:
+        """发送好友特效文本消息"""
+        return self.post(
+            'SendMsgV2',
+            {
+                "ToUserUid": user,
+                "SendToType": 1,
+                "SendMsgType": "TeXiaoTextMsg",
+                "Content": text,
+            },
+        )
+
     def sendGroupText(
         self, group: int, content: str, atUser: Union[int, List[int]] = 0
     ) -> dict:
@@ -188,6 +200,18 @@ class Action:
             },
         )
 
+    def sendGroupTeXiaoText(self, group: int, text: str) -> dict:
+        """发送群组特效文本消息"""
+        return self.post(
+            'SendMsgV2',
+            {
+                "ToUserUid": group,
+                "SendToType": 2,
+                "SendMsgType": "TeXiaoTextMsg",
+                "Content": text,
+            },
+        )
+
     def sendPrivateText(self, user: int, group: int, content: str) -> dict:
         """发送私聊文本消息"""
         return self.post(
@@ -398,9 +422,13 @@ class Action:
         return self.get('GetUserCook')
 
     def getUserInfo(self, user: int) -> dict:
-        """获取任意用户信息昵称头像等"""
+        """获取用户信息昵称头像等"""
         return self.post('GetUserInfo', {'UserID': user})
 
+    def getSummaryCard(self, user: int) -> dict:
+        """获取企鹅卡片资料"""
+        return self.post('SummaryCard.ReqSummaryCard', {'UserID': user})
+
     def getUserList(self) -> List[dict]:
         """获取好友列表"""
         friend_list = []
